==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/desktop-utils/lumina-fileinfo/i18n/l-fileinfo_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <location filename="../MainUI.ui" line="24"/>
        <location filename="../MainUI.cpp" line="97"/>
        <source>File Information</source>
        <translation>Informazioni File</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="56"/>
        <source>Owner:</source>
        <translation>Proprietario:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="73"/>
        <source>Group:</source>
        <translation>Gruppo:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Permissions:</source>
        <translation>Permessi:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="104"/>
        <source>Created:</source>
        <translation>Creato il:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="111"/>
        <source>Note: The time a file was created might be more recent than the time modified if the file permissions were changed recently.</source>
        <translation>Nota: Il tempo di creazione del file potrebbe essere più recente rispetto al tempo delle modifiche se i permessi dei file sono state modificati di recente.</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Last Modified:</source>
        <translation>Ultima modifica:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="131"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>MimeType:</source>
        <translation>Tipo Mime</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="185"/>
        <source>File Size:</source>
        <translation>Dimensione File:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="216"/>
        <location filename="../MainUI.cpp" line="140"/>
        <source>Edit Shortcut</source>
        <translation>Edita Shortcut</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="239"/>
        <source>Working Dir:</source>
        <translation>Cartella di lavoro:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="246"/>
        <source>Use startup notification</source>
        <translation>Usa notifica di avvio</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="260"/>
        <source>Icon:</source>
        <translation>Icona:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="267"/>
        <source>Command:</source>
        <translation>Comando:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="274"/>
        <source>Comment:</source>
        <translation>Commento:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="284"/>
        <source>Run in terminal</source>
        <translation>Eseguire nel terminale</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="291"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="336"/>
        <source>No Icon</source>
        <translation>Nessuna icona</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="392"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="405"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="61"/>
        <source>---Calculating---</source>
        <translation>--- Calcolo ---</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="70"/>
        <source>Read/Write</source>
        <translation>Lettura/Scrittura</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="71"/>
        <source>Read Only</source>
        <translation>Sola lettura</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="72"/>
        <source>Write Only</source>
        <translation>Sola scrittura</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="73"/>
        <source>No Access</source>
        <translation>Nessun accesso</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="77"/>
        <source>XDG Shortcut</source>
        <translation>Shortcut XDG</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="78"/>
        <source>Directory</source>
        <translation>Directory</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="79"/>
        <source>Binary</source>
        <translation>Binario</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="81"/>
        <source>Hidden %1</source>
        <translation> %1 Nascosto</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="126"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="249"/>
        <source>Save Application File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="249"/>
        <source>Application Registrations (*.desktop)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="290"/>
        <source>Select a binary</source>
        <translation>Seleziona un binario</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="293"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="293"/>
        <source>Invalid selection: Not a valid executable</source>
        <translation>Scelta invalida: Eseguibile non valido</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="305"/>
        <source>Select a directory</source>
        <translation>Seleziona una directory</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="318"/>
        <source>Select an icon</source>
        <translation>Seleziona un&apos;icona</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="318"/>
        <source>Images (%1);; All Files (*)</source>
        <translation>Immagini (%1);; Tutti i  File (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <location filename="../MainUI.cpp" line="343"/>
        <source> Folders: </source>
        <translation>_Cartelle:  </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <location filename="../MainUI.cpp" line="343"/>
        <source>Files: </source>
        <translation>File: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="343"/>
        <source>  Calculating...</source>
        <translation>  Calcolo in corso...</translation>
    </message>
</context>
</TS>

==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/desktop-utils/lumina-fileinfo/i18n/l-fileinfo_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <location filename="../MainUI.ui" line="24"/>
        <location filename="../MainUI.cpp" line="96"/>
        <source>File Information</source>
        <translation>Informazioni File</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="56"/>
        <source>Owner:</source>
        <translation>Proprietario:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="73"/>
        <source>Group:</source>
        <translation>Gruppo:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Permissions:</source>
        <translation>Permessi:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="104"/>
        <source>Created:</source>
        <translation>Creato il:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="111"/>
        <source>Note: The time a file was created might be more recent than the time modified if the file permissions were changed recently.</source>
        <translation>Nota: Il tempo di creazione del file potrebbe essere più recente rispetto al tempo delle modifiche se i permessi dei file sono state modificati di recente.</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Last Modified:</source>
        <translation>Ultima modifica:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="131"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>MimeType:</source>
        <translation>Tipo Mime:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="185"/>
        <source>File Size:</source>
        <translation>Dimensione File:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="216"/>
        <location filename="../MainUI.cpp" line="139"/>
        <source>Edit Shortcut</source>
        <translation>Edita Shortcut</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="239"/>
        <source>Working Dir:</source>
        <translation>Cartella di lavoro:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="246"/>
        <source>Use startup notification</source>
        <translation>Usa notifica di avvio</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="260"/>
        <source>Icon:</source>
        <translation>Icona:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="267"/>
        <source>Command:</source>
        <translation>Comando:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="274"/>
        <source>Comment:</source>
        <translation>Commento:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="284"/>
        <source>Run in terminal</source>
        <translation>Eseguire nel terminale</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="291"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="336"/>
        <source>No Icon</source>
        <translation>Nessuna icona</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="392"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="405"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="60"/>
        <source>---Calculating---</source>
        <translation>--- Calcolo ---</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="69"/>
        <source>Read/Write</source>
        <translation>Lettura/Scrittura</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="70"/>
        <source>Read Only</source>
        <translation>Sola lettura</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="71"/>
        <source>Write Only</source>
        <translation>Sola scrittura</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="72"/>
        <source>No Access</source>
        <translation>Nessun accesso</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="76"/>
        <source>XDG Shortcut</source>
        <translation>Shortcut XDG</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="77"/>
        <source>Directory</source>
        <translation>Cartella</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="78"/>
        <source>Binary</source>
        <translation>Binario</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="80"/>
        <source>Hidden %1</source>
        <translation>%1 Nascosto</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="125"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="247"/>
        <source>Save Application File</source>
        <translation>Salva il file dell&apos;Applicazione</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="247"/>
        <source>Application Registrations (*.desktop)</source>
        <translation>Registrazioni delle Applicazioni (*.scrivania)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="288"/>
        <source>Select a binary</source>
        <translation>Seleziona un binario</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="291"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="291"/>
        <source>Invalid selection: Not a valid executable</source>
        <translation>Scelta invalida: Eseguibile non valido</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="303"/>
        <source>Select a directory</source>
        <translation>Seleziona una directory</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="316"/>
        <source>Select an icon</source>
        <translation>Seleziona un&apos;icona</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="316"/>
        <source>Images (%1);; All Files (*)</source>
        <translation>Immagini (%1);; Tutti i  File (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="339"/>
        <location filename="../MainUI.cpp" line="341"/>
        <source> Folders: </source>
        <translation> Cartelle: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="339"/>
        <location filename="../MainUI.cpp" line="341"/>
        <source>Files: </source>
        <translation>File: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <source>  Calculating...</source>
        <translation>  Calcolo in corso...</translation>
    </message>
</context>
</TS>
